% A New Keynesian model in a small open economy
% Replicates the model from "On fiscal multipliers in New Keynesian small 
%   open economy models" by Philip Schuster
% Philip Schuster Nov 14, 2019, philip.schuster@oenb.at

function out = calibfind(xcalib0)

  global param ss

  attach_struct(param)
  attach_struct(ss)
  
  tauL0    = xcalib0(1);
  rho      = xcalib0(2);  % find rho for given TB0
  DFguess  = xcalib0(3);

  Delta0   = PC0/(1-parhabit*gam/(1+iW0));
  Lambda0  = Delta0*PC0^(-sig)/(1-(1/(1+rho))^sig*(1+iW0)^(sig-1)*gam);
  Omega0   = Lambda0*PC0^(sig-1);

  ConsC0   = (WW0*LS0-Ph0*tauL0-Ph0*tauLC0)/PC0;
  ConsCtilde = ConsC0-parhabit*gam*ConsC0;

  ConsUtemp  = (Cons0-(1-unconst)*ConsC0)/unconst;
  ConsUtilde = ConsUtemp-parhabit*gam*ConsUtemp;

  MU_Cons0 = (unconst*ConsUtilde+(1-unconst)*ConsCtilde)^(-sigC);
 
  thetaL  = WW0/PC0*MU_Cons0*LStilde0^(-sigell)/markupW0; % using W0=Wstar0
  
  if (isfinite(epsilonW))
      xW10     = thetaL*W0^(epsilonW)*LS0*LStilde0^sigell/(1-phiW/(1+rho));
      xW20     = (1-tauW0)*MU_Cons0/PC0*W0^(epsilonW)*LS0/(1-phiW/(1+rho));
  else
      xW10     = thetaL*LStilde0^sigell;
      xW20     = (1-tauW0)*MU_Cons0/PC0;
  end

  H0      = unconst*(1+iW0)*(WW0*LS0-Ph0*tauL0)/(iW0+1-gam); % aggregated
  ConsUagg = (V0+VC0+DG0+DFguess+H0)/(Omega0*PC0*(1-parhabit*gam*(1-Delta0/(Omega0*PC0)))); % aggregated
  ConsU0  = ConsUagg/unconst;
  Consguess = unconst*ConsU0+(1-unconst)*ConsC0;
  TaxL0   = Ph0*(tauL0+(1-unconst)*tauLC0);
  A0      = (1+iW0)*(PC0*Cons0-WW0*LS0+TaxL0)/iW0; % tauL incl. dM
  Sav0    = A0+WW0*LS0-PC0*Cons0-TaxL0;

  E0      = Y0-FC0-Invh0-Consh0-CGh0-IGh0;
  E_0     = exp(log(Ph0)-E0/sigExport);
  TB0     = Ph0*E0-Pm0*(Consm0+Invm0+CGm0+IGm0);
  DF0     = -TB0*(1+i0)/i0;

  TaxCbase0    = PCtilde0*Cons0;
  TaxFbase0    = W0*LD0;
  TaxKbase0    = PK0*Khat0;
  TaxRbase0    = i0/(1+i0)*Sav0;
  TaxWbase0    = W0*LS0;
  Taxprofbase0 = Ph0*(Y0-FC0)-PInv0*delta_0*K0-tauK0*PK0*Khat0-WF0*LD0;
  
  TaxF0   = tauF0*TaxFbase0;
  TaxK0   = tauK0*TaxKbase0;
  TaxR0   = tauR0*TaxRbase0;
  TaxW0   = tauW0*TaxWbase0;
  Taxprof0= tauprof0*Taxprofbase0;

  Rev0    = TaxC0+TaxF0+TaxK0+TaxL0+TaxR0+TaxW0+Taxprof0;
  Exp0    = PG0*CG0+PIG0*IG0+subI0*PInv0*Inv0+Ph0*subL0;
  PB0     = DG0*i0/(1+i0);

  GDPr0   = PC0*Cons0+PInv0*(Inv0+J0)+PG0*CG0+PIG0*IG0+TB0;

  eda0    = V0+VC0+DG0+DF0-A0;
  edy0    = Consh0+CGh0+Invh0+IGh0+E0+FC0-Y0;
  edl0    = LD0-LS0;
  edg0    = Rev0-Exp0-PB0;
  edv0    = Ph0*edy0+W0*edl0+i0/(1+i0)*eda0+edg0; % WALRAS LAW, PK0*edk0 = 0 by construction

  out(1) = edg0;
  out(2) = Consguess-Cons0;
  out(3) = DFguess-DF0;
  
  param.rho       = rho;
  param.thetaL    = thetaL;
  param.E_0       = E_0;
  
  ss.tauL0        = tauL0;
  ss.Delta0       = Delta0;
  ss.Lambda0      = Lambda0;
  ss.Omega0       = Omega0;
  ss.ConsC0       = ConsC0;
  ss.ConsCtilde0  = ConsCtilde;
  ss.ConsU0       = ConsU0;
  ss.ConsUtilde0  = ConsUtilde;
  ss.Cons0        = Cons0;
  ss.MU_Cons0     = MU_Cons0;
  ss.H0           = H0/unconst;             % convert aggregated H0 to per capita of unconst
  ss.A0           = A0;
  ss.Sav0         = Sav0;
  ss.E0           = E0;
  ss.TB0          = TB0;
  ss.DF0          = DF0;
  ss.TaxCbase0    = TaxCbase0;
  ss.TaxFbase0    = TaxFbase0;
  ss.TaxKbase0    = TaxKbase0;
  ss.TaxRbase0    = TaxRbase0;
  ss.TaxWbase0    = TaxWbase0;
  ss.Taxprofbase0 = Taxprofbase0;
  ss.Rev0         = Rev0;
  ss.Exp0         = Exp0;
  ss.PB0          = PB0-ss.Ph0*ss.tauL0;    % exclude lump-sum taxes from primary balance
  ss.GDPr0        = GDPr0;
  ss.xW10         = xW10;
  ss.xW20         = xW20;
  
  ss.eda0         = eda0;
  ss.edy0         = edy0;
  ss.edl0         = edl0;
  ss.edg0         = edg0;
  ss.edv0         = edv0;
  
  ss.ConsUtemp    = ConsUtemp;
 
end

