% A New Keynesian model in a small open economy
% Replicates the model from "On fiscal multipliers in New Keynesian small 
%   open economy models" by Philip Schuster
% Philip Schuster Nov 14, 2019, philip.schuster@oenb.at

function out = calibfind_delta(x_in)
    
  global param ss
  
  attach_struct(param);
  attach_struct(ss);
  
  delta_0  = x_in;
  
  % capacity utilization
  delta_1  = i0+delta_0*(1-tauprof0/(1-subI0));

  if (isfinite(delta_2))
    delta0   = delta_0+delta_1*(o0-1)+delta_2/2*(o0-1)^2;
  else
    delta0   = delta_0;
  end

  PK0      = ((i0+delta0)*(1-subI0)-delta_0*tauprof0)*PInv0/(o0*(1-tauprof0));
  PF0      = (1+tauK0)*PK0;
  
  Khat0    = (Ph0*Y0/markup0-LD0*WF0)/PF0; % includes profits
  alpha    = Khat0*PF0^sigmaP/(Khat0*PF0^sigmaP+LD0*WF0^sigmaP);

  if (sigmaP == 1)
    TFP0   = Y0/(Khat0^alpha*LD0^(1-alpha));
  else
    TFP0   = Y0/(alpha^(1/sigmaP)*Khat0^((sigmaP-1)/sigmaP)+(1-alpha)^(1/sigmaP)*LD0^((sigmaP-1)/sigmaP))^(sigmaP/(sigmaP-1));
  end

  K0       = Khat0/o0;
  Invguess = K0*delta0;
  J0       = 1/2*Psi*K0*(Inv0/K0-delta_0)^2;

  Div0     = (1-tauprof0)*(Ph0*(Y0-FC0)-WF0*LD0-PF0*Khat0);
  V0       = (1+i0)*Div0/i0;
  VR0      = (1+i0)*Ph0*subL0/i0;
  TF0      = tauprof0*(PK0*Khat0-PInv0*delta_0*K0)-subL0*Ph0-subI0*PInv0*Inv0;
  DivC0    = PK0*Khat0-PInv0*(Inv0+J0)-TF0;
  VC0      = (1+i0)*DivC0/i0;
  
  q0       = (1+i0)*PInv0*(1-subI0);

  ss.PK0           = PK0;
  ss.PF0           = PF0;
  ss.Khat0         = Khat0;
  ss.TFP0          = TFP0;
  ss.K0            = K0;
  ss.J0            = J0;
  ss.Div0          = Div0;
  ss.V0            = V0;
  ss.VR0           = VR0;
  ss.TF0           = TF0;
  ss.DivC0         = DivC0;
  ss.VC0           = VC0;
  ss.q0            = q0;
  ss.delta0        = delta0;
  
  param.alpha         = alpha;
  param.delta_0       = delta_0;
  param.delta_1       = delta_1;
  
  out = Invguess-Inv0;

end

